#!/usr/bin/env node
const Server = require('./src/server')
const OctoDash  = require('octodash')
const packageJSON = require('./package.json')

const CLI_OPTIONS = [
  {
    names: ['azure-iot-connection-string','a'],
    type: 'string',
    required: true,
    env: 'AZURE_IOT_CONNECTION_STRING',
    help: 'The hostname for Azure IOT',
    helpArg: 'string',
  },
  {
    names: ['uuid', 'u'],
    type: 'string',
    env: 'MESHBLU_UUID',
    required: true,
    help: 'Meshblu UUID',
    helpArg: 'UUID',
  },
  {
    names: ['token', 't'],
    type: 'string',
    env: 'MESHBLU_TOKEN',
    required: true,
    help: 'Meshblu Token',
    helpArg: 'TOKEN',
  },
  {
    names: ['domain', 'd'],
    type: 'string',
    default: 'octoblu.com',
    env: 'MESHBLU_DOMAIN',
    help: 'Meshblu SRV Domain',
    helpArg: 'DOMAIN',
  },
]
class Command {
  constructor({argv, cliOptions = CLI_OPTIONS} = {}) {
    this.octoDash = new OctoDash({
      argv,
      cliOptions,
      name: packageJSON.name,
      version: packageJSON.version,
    })

    const { azureIotConnectionString, uuid, token, domain } = this.octoDash.parseOptions()
    const meshbluConfig = { uuid, token, domain, resolveSrv: true }

    this.server = new Server({ azureIotConnectionString, meshbluConfig })
  }

  panic(error) {
    console.error(error.stack) // eslint-disable-line no-console
    process.exit(1)
  }

  panicIfError(error) {
    if (!error) return
    this.panic(error)
  }

  run() {
    this.server.run(this.panicIfError)
  }
}

if (require.main === module) {
  const command = new Command({ argv: process.argv })
  command.run()
}

module.exports = Command
